from profanityfilter import ProfanityFilter
from google import genai
import sys
import keyring

SERVICE_NAME = "chatfilter"  # Used to store the API key securely

class ChatFilter:
    def __init__(self):
        self.pf = ProfanityFilter()
        self.pf.set_censor("♡")

        api_key = keyring.get_password(SERVICE_NAME, "api_key")
        if not api_key:
            print("No API key found. Run the command with '--setup' to set it up.")
            sys.exit(1)

        self.client = genai.Client(api_key=api_key)
        self.chat = self.client.chats.create(model="gemini-2.0-flash")

    def get_input(self):
        return input("-> ")

    def filter_text(self, text):
        return self.pf.censor(text)

    def send_message(self, message):
        response = self.chat.send_message(message)
        return response.candidates[0].content.parts[0].text

    def run(self):
        print("Type 'exit' to quit.")
        while True:
            user_text = self.get_input()
            if user_text.lower() == 'exit':
                print("Exiting chat...")
                sys.exit(0)
            filtered_text = self.filter_text(user_text)
            response_text = self.send_message(filtered_text)
            print(response_text)

def setup_api_key():
    """Prompt the user to enter their API key and store it securely."""
    api_key = input("Enter your API key: ").strip()
    keyring.set_password(SERVICE_NAME, "api_key", api_key)
    print("API key saved successfully!")

def main():
    if "--setup" in sys.argv:
        setup_api_key()
    else:
        chat_app = ChatFilter()
        chat_app.run()

if __name__ == '__main__':
    main()
